@@ -36,7 +36,9 @@ class Irradiance():
     #WD10m: 10-m wind direction (0 = N
     #SP: Surface (air) pressure (Pa)
 
-    _,data,_ = PVGIS().retrieve_tmy(location.latitude,location.longitude)
+    inputs ,data, metadata = PVGIS().retrieve_tmy(location.latitude,location.longitude)
+
+
 
     data.rename(columns = {'G(h)':'GHI',
                            'Gd(h)':'DHI',
@@ -48,16 +50,29 @@ class Irradiance():
                            'SP':'Air pressure',
                           }, inplace = True)
 
-
-
+  
     data['Time_H'] = data.index.strftime("%H").astype(float)
     data['Time_M'] = data.index.strftime("%M").astype(float)
     data['Time_S'] = data.index.strftime("%S").astype(float)
 
+    new_index = data.index.map(lambda t: t.replace(year=2030))
+    data=data.set_index(new_index)
+
+
+
+
+    df_both = pd.date_range("2030-01-01 00:00:00", "2030-12-31 23:00:00", freq='30T').to_frame()
+    df_both = df_both.drop([0], axis=1)
+    df_both = df_both.merge(data, left_index=True, right_index=True, how='left')
+    data = df_both.interpolate(method='spline', order=2)
+
+
     DOY =  pd.DatetimeIndex(data.index.values).day_of_year
     data['Declination'] = (23.45*np.sin(np.deg2rad((360/365)*(284+DOY)))).values
 
     omega = 0.25*(data['Time_H']*60+data['Time_M']+data['Time_S']/60-12*60)
+    data = data.drop(['Time_H', 'Time_M','Time_S'], axis=1)
+
     data['Hour angle'] = omega
 
     psi = np.arccos(math.sin(np.deg2rad(location.latitude))*np.sin(np.deg2rad(data['Declination']))+math.cos(np.deg2rad(location.latitude))*np.cos(np.deg2rad(data['Declination']))*np.cos(np.deg2rad(omega)))*180/math.pi
@@ -82,11 +97,18 @@ class Irradiance():
     data['Rb_rear'] = abs(np.where( (data['Hour angle']< (azimuth - 90)) | (data['Hour angle'] > (azimuth + 90)), cos_phi/cos_psi, 0))
 
 
+
+    cols = ['Rb_front', 'Rb_rear']
+    data[cols] = data[cols].clip(upper=1)
+    
+    data[['GHI', 'DHI','DNI']] = data[['GHI', 'DHI','DNI']].clip(lower=0)
+
+
     data['DOY'] = DOY
     data['Solar Zenith angle'] = psi
-    data = data.drop(['Time_H', 'Time_M','Time_S'], axis=1)
+    
 
-    return data
+    return inputs ,data, metadata
 
 
 
@@ -100,7 +122,7 @@ class Irradiance():
 
   def irradiance(self, module, location, panel_tilt:float=35, albedo:float=0.2, azimuth:float = 0, Elevation=2, panel_distance:float = None):
 
-    data = Irradiance()._get_TMY(location, panel_tilt, azimuth)
+    inputs ,data, metadata = Irradiance()._get_TMY(location, panel_tilt, azimuth)
 
 
     if panel_distance == None:
@@ -114,7 +136,7 @@ class Irradiance():
 
     if module['BIPV'] == 'N' :
       data['Total_G'] = G_front
-      return data
+      return inputs ,data, metadata
 
 
     GR_beam = Irradiance()._GR_beam(data)
@@ -125,7 +147,7 @@ class Irradiance():
     data['G_Rear'] = G_Rear
     data['Total_G'] = G_Rear + G_front
 
-    return data
+    return inputs ,data, metadata
 
 
 
@@ -431,11 +453,11 @@ class Irradiance():
     return albedo_list
 
 
+#location = Location().set_location("Oeiras")
+#module = Modules().module('6MN6A270')
+
+#_,data,_ = Irradiance().irradiance(module, location, 35, 0.2)
 
-#data = Irradiance().irradiance(module, location, 35, 0.2)
-#print(location.get_info())
 #display(data.head(24))
-
 #data[['G_Front','G_Rear','Total_G']].max()
-
 #data.to_csv("csv.csv")
\ No newline at end of file
